Sample

Struct Sample 

pub struct Sample {
    pub location_id: Vec<u64>,
    pub value: Vec<i64>,
    pub label: Vec<Label>,
}
Each Sample records values encountered in some program context. The program context is typically a stack trace, perhaps augmented with auxiliary information like the thread-id, some indicator of a higher level request being handled etc.

Fields

location_id: Vec<u64>

The ids recorded here correspond to a Profile.location.id. The leaf is at location_id[0].

value: Vec<i64>

The type and unit of each value is defined by the corresponding entry in Profile.sample_type. All samples must have the same number of values, the same as the length of Profile.sample_type. When aggregating multiple samples into a single sample, the result has a list of values that is the element-wise sum of the lists of the originals.

label: Vec<Label>

label includes additional context for this sample. It can include things like a thread id, allocation size, etc.

NOTE: While possible, having multiple values for the same label key is strongly discouraged and should never be used. Most tools (e.g. pprof) do not have good (or any) support for multi-value labels. And an even more discouraged case is having a string label and a numeric label of the same name on a sample. Again, possible to express, but should not be used.